Skip to contents

Translate a function name from a locale to English.

Usage

.locale_to_english(fn_name, locale)

Arguments

fn_name

Function name string (any case).

locale

Locale code or NULL (returns fn unchanged).

Value

English function name, or fn unchanged if no mapping found.