List supported locale codes.
supported_locales.RdReturns the locale columns present in the cached function table, i.e.
the locales for which at least partial translation data was loaded.
Returns character(0) if setup_terminology() hasn't been run.