Find the closest known function name(s) to an unknown token.
dot-spell_suggest.RdUses generalised edit distance (utils::adist) over the worksheet-function registry (LEGACY_WORKSHEET ∪ XLFN ∪ XLWS). XLM macro names are excluded from suggestions since user typos in worksheet contexts are almost never typos of XLM names.